@@ -53,6 +53,9 @@ import java.util.Dictionary;
 import java.util.Hashtable;
 import org.osgi.service.http.HttpService;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.ForcedReloadable;
+import com.openexchange.config.Interests;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.mail.service.MailService;
@@ -61,15 +64,14 @@ import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.spamhandler.SpamHandler;
 import com.openexchange.spamhandler.spamexperts.SpamExpertsSpamHandler;
 import com.openexchange.spamhandler.spamexperts.management.SpamExpertsConfig;
+import com.openexchange.spamhandler.spamexperts.servlets.SpamExpertsServlet;
 import com.openexchange.tools.servlet.http.HTTPServletRegistration;
 import com.openexchange.user.UserService;
 
 public class SpamExpertsActivator extends HousekeepingActivator {
 
-	private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SpamExpertsActivator.class);
-
 	private HTTPServletRegistration servletRegistration;
-
+    private SpamExpertsServlet spamExpertsServlet;
 
 	public SpamExpertsActivator() {
 		super();
@@ -77,37 +79,57 @@ public class SpamExpertsActivator extends HousekeepingActivator {
 
 	@Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { UserService.class, DatabaseService.class, ContextService.class, ConfigurationService.class, HttpService.class, MailService.class, SSLSocketFactoryProvider.class };
+        return new Class<?>[] { UserService.class, DatabaseService.class, ContextService.class, ConfigurationService.class, ConfigViewFactory.class, HttpService.class, MailService.class, SSLSocketFactoryProvider.class };
     }
 
 	@Override
 	protected synchronized void startBundle() throws Exception {
-        LOG.info("starting bundle: \"com.openexchange.spamhandler.spamexperts\"");
-        Services.setServiceLookup(this);
+	    org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(SpamExpertsActivator.class);
+        logger.info("starting bundle: \"com.openexchange.spamhandler.spamexperts\"");
 
-		try {
-		    Dictionary<String, String> dictionary = new Hashtable<String, String>(2);
-	        dictionary.put("name", SpamExpertsSpamHandler.getInstance().getSpamHandlerName());
-			SpamExpertsConfig.getInstance().start();
-			registerService(SpamHandler.class, SpamExpertsSpamHandler.getInstance(), dictionary);
-			servletRegistration = new HTTPServletRegistration(context, new com.openexchange.spamhandler.spamexperts.servlets.SpamExpertsServlet(), SpamExpertsConfig.getInstance().getPanelServlet());
-		} catch (final Exception t) {
-			LOG.error("", t);
-			throw t;
-		}
+	    final SpamExpertsConfig config = new SpamExpertsConfig(this);
 
+	    SpamExpertsSpamHandler spamHandler = new SpamExpertsSpamHandler(config, this);
+	    Dictionary<String, String> dictionary = new Hashtable<String, String>(2);
+        dictionary.put("name", spamHandler.getSpamHandlerName());
+        registerService(SpamHandler.class, spamHandler, dictionary);
+
+        registerService(ForcedReloadable.class, new ForcedReloadable() {
+
+            @Override
+            public void reloadConfiguration(ConfigurationService configService) {
+                config.clearCache();
+            }
+
+            @Override
+            public Interests getInterests() {
+                return null;
+            }
+        });
+
+        String alias = getService(ConfigurationService.class).getProperty("com.openexchange.custom.spamexperts.panel_servlet", "/ajax/spamexperts/panel").trim();
+		SpamExpertsServlet spamExpertsServlet = new SpamExpertsServlet(config);
+		this.spamExpertsServlet = spamExpertsServlet;
+        servletRegistration = new HTTPServletRegistration(context, spamExpertsServlet, alias);
 	}
 
 	@Override
 	protected synchronized void stopBundle() throws Exception {
-        LOG.info("stopping bundle: \"com.openexchange.spamhandler.spamexperts\"");
+	    org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(SpamExpertsActivator.class);
+        logger.info("stopping bundle: \"com.openexchange.spamhandler.spamexperts\"");
 
+        HTTPServletRegistration servletRegistration = this.servletRegistration;
         if (servletRegistration != null) {
+            this.servletRegistration = null;
             servletRegistration.unregister();
-            servletRegistration = null;
         }
 
-        Services.setServiceLookup(null);
+        SpamExpertsServlet spamExpertsServlet = this.spamExpertsServlet;
+        if (null != spamExpertsServlet) {
+            this.spamExpertsServlet = null;
+            spamExpertsServlet.shutDown();
+        }
+
         super.stopBundle();
 	}
 
